# mt-ban-ascii.pl
# - Deny or moderate ASCII or Latin-1 comment using MT3 CommentFilter API
#
# It requires Perl 5.8 or over.
#
# Author:  Tatsuhiko Miyagawa <miyagawa at bulknews.net>
# License: same as Perl
#
# Ported to MT 3.3 TBPingThrottleFilter by Yujiro ARAKI.
# asciiTBPingfilter.pl
# 2008.11.10 0.01

package MT::Plugin::asciiCommentfilter;

use strict;
use MT;
use base qw(MT::Plugin);

our $VERSION;

# logging
our $log = 0;

sub BEGIN {
    $VERSION = '0.01';
    my $plugin = MT::Plugin::asciiCommentfilter->new ({
        name => 'ASCII Comment Filter Plugin',
        description => 'Filter only ascii comment.',
        doc_link => 'http://www.koikikukan.com/archives/2008/11/10-005555.php',
        version => $VERSION,
        blog_config_template => 'config.tmpl',
        settings => new MT::PluginSettings ([
        ['asciiCommentfilter', { Default => '1', Scope => 'blog' }],
        ]),
        });
    MT->add_plugin($plugin);
    MT->add_callback('CommentThrottleFilter', 5, $plugin, sub { ascii_comment_filter($plugin, @_) });
}

sub ascii_comment_filter {
    my $plugin = shift;
    my($cb, $app, $entry) = @_;

    my $id = $entry->blog_id;
    my $flag = $plugin->get_config_value('asciiCommentfilter', "blog:$id");
    return 1 if !$flag;

    eval { require Encode; };
    if ($@) {
        $app->log("Please use perl 5.8 for this plugin.");
        return 1;
    }
    my $q = $app->{query};
    my $text = Encode::decode(MT::ConfigMgr->instance->PublishCharset, $q->param('text') || '');
    if ($text =~ /^[\x00-\xff]+$/) {
        $app->log("Filter ascii comment. URL:" . $q->param('url')) if $log;
        return 0;
    }
    return 1;
}

1;
